@@ -18,3 +18,8 @@ from vitrage_tempest_plugin.tests.common.tempest_clients import TempestClients
 def get_public_network():
     nets = TempestClients.neutron().list_networks()
     return g_utils.first_match(nets['networks'], name='public')
+
+
+def get_shared_network():
+    nets = TempestClients.neutron().list_networks()
+    return g_utils.first_match(nets['networks'], name='shared')
